@@ -1,6 +1,7 @@
 import io
 import os
 from typing import Union
+
 from typing.io import BinaryIO
 
 from .compression import CompressionFactory
@@ -24,16 +25,15 @@ class ToVariableWriter:
 
 def save_object(
     obj: Union[bytes, BinaryIO],
-    name,
-    path=None,
+    file_name: str,
+    path: str,
     compression: CompressionFactory = CompressionFactory.NONE,
 ) -> str:
     compression = compression.value()
     if isinstance(obj, bytes):
         obj = io.BytesIO(obj)
-    if path is not None:
-        name = f"{os.path.join(path, name)}"
-    save_path = f"{name}{compression.extension}"
+    file_name = f"{file_name}{compression.extension}"
+    save_path = os.path.join(path, file_name)
     with open(save_path, "wb") as out_file:
         compression.compress(read_stream=obj, write_stream=out_file)
     return save_path
@@ -45,6 +45,7 @@ def load_object(path, as_bytes=True) -> Union[str, bytes]:
     to_var = ToVariableWriter()
     with open(path, "rb") as in_file:
         compression.decompress(read_stream=in_file, write_stream=to_var)
+        in_file.close()
     if as_bytes:
         return to_var.data_bytes
     return to_var.data_str
